@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThread.h 1899 2006-10-28 14:22:47Z svn $
+ * $Id: BBSThread.h 1951 2006-11-08 11:31:58Z svn $
  *****************************************************************************/
 
 #ifndef BBS_THREAD_H
@@ -91,6 +91,12 @@ public:
         const char *message;
         /** メッセージの長さ */
         apr_size_t message_length;
+        /** 添付画像の拡張子 */
+        const char *image_ext;
+        /** サムネイル画像の横サイズ */
+        apr_uint16_t thumb_width;
+        /** サムネイル画像の縦サイズ */
+        apr_uint16_t thumb_height;
         union {
             bbs_comment_flag_t flag;
             apr_size_t flag_data;
@@ -104,7 +110,10 @@ public:
             trip(NULL),
             email(NULL),
             message(NULL),
-            message_length(0)
+            message_length(0),
+            image_ext(""),
+            thumb_width(0),
+            thumb_height(0)
         {
             flag_data = 0;
         };
@@ -145,8 +154,6 @@ public:
         apr_size_t      id;
         /** スレッドの題名 */
         char            subject[TRD_MAX_SUBJECT_SIZE];
-        /** 添付画像 */
-        image_t         image;
         /** スレッドの最終更新日時 */
         apr_time_t      mtime;
         /** スレッドの最終 age 日時 */
@@ -166,11 +173,13 @@ public:
      * @param[in] trip トリップ
      * @param[in] email メールアドレス
      * @param[in] message メッセージ
+     * @param[in] image 添付画像
      * @param[in] time 書き込み時刻
      * @param[in] is_age age かどうか
      */
     void add_comment(const char *name, const char *trip, const char *email,
-                     const char *message, apr_time_t time, bool is_age);
+                     const char *message, BBSThread::image_t *image,
+                     apr_time_t time, bool is_age);
     /**
      * コメントを読み出します．
      *
@@ -217,22 +226,6 @@ public:
     {
         return bthread_.subject;
     }
-    const char *get_image_ext() const
-    {
-        return bthread_.image.ext;
-    }
-    apr_size_t get_image_size() const
-    {
-        return bthread_.image.size;
-    }
-    apr_uint16_t get_thumbnail_width() const
-    {
-        return bthread_.image.thumbnail.width;
-    }
-    apr_uint16_t get_thumbnail_height() const
-    {
-        return bthread_.image.thumbnail.height;
-    }
     apr_uint16_t get_comment_count() const
     {
         return bthread_.comment_count;
@@ -268,29 +261,20 @@ public:
      * @paramp[out] memory メモリ
      * @paramp[in] thread_id スレッドの ID
      * @paramp[in] subject スレッドの題名
-     * @param[in] image_ext 添付画像の拡張子
-     * @param[in] image_size 添付画像のサイズ
      * @paramp[in] time スレッドの生成日時
+     * @paramp[in] is_need_validate 内容をチェックするかどうか
      * @return インスタンス
      */
     static BBSThread *get_instance(void *memory, apr_size_t thread_id,
-                                   const char *subject, image_t *image,
-                                   apr_time_t time);
-    /**
-     * メモリを使ってインスタンスを生成します．
-     *
-     * @paramp[out] memory メモリ
-     * @paramp[in] thread_id スレッドの ID
-     * @paramp[in] subject スレッドの題名
-     * @paramp[in] time スレッドの生成日時
-     * @return インスタンス
-     */
-    static BBSThread *get_instance(void *memory, apr_size_t thread_id,
-                                   const char *subject, apr_time_t time);
+                                   const char *subject, apr_time_t time,
+                                   bool is_need_validate=true);
     /**
      * プールを使ってインスタンスを生成します．
      *
      * @paramp[in] pool プール
+     * @paramp[in] thread_id スレッドの ID
+     * @paramp[in] subject スレッドの題名
+     * @paramp[in] time スレッドの生成日時
      * @return インスタンス
      */
     static BBSThread *get_instance(apr_pool_t *pool, apr_size_t thread_id=0,
@@ -318,23 +302,29 @@ private:
      */
     typedef struct bbs_comment {
         /** 書き込み日時 */
-        apr_time_t time;
+        apr_time_t      time;
         /** メッセージのデータサイズ */
-        apr_uint16_t size;
+        apr_uint16_t    size;
         /** 書き込み日時 (フォーマット済み) の開始位置のオフセット */
-        apr_uint16_t date_offset;
+        apr_uint16_t    date_offset;
         /** トリップの開始位置のオフセット */
-        apr_uint16_t trip_offset;
+        apr_uint16_t    trip_offset;
         /** メールアドレス開始位置のオフセット */
-        apr_uint16_t email_offset;
+        apr_uint16_t    email_offset;
         /** メッセージ開始位置のオフセット */
-        apr_uint16_t message_offset;
+        apr_uint16_t    message_offset;
         /** メッセージの長さ */
-        apr_uint16_t message_length;
+        apr_uint16_t    message_length;
+        /** 添付画像 */
+        image_t         image;
         union {
             bbs_comment_flag_t flag;
             apr_size_t flag_data;
         };
+#ifndef WIN32
+        // VisualStudio 2005 が挿入する謎のパディング
+        apr_size_t      padding;
+#endif
     } bbs_comment_t;
 
     /**
@@ -352,18 +342,16 @@ private:
         char            subject[TRD_MAX_SUBJECT_SIZE];
         /** ステータス (ビットマップ) */
         apr_size_t      status;
-        /** 添付画像 */
-        image_t         image;
         /** スレッドの ID */
         apr_size_t      id;
-        /** コメント末尾のオフセット */
-        apr_size_t      comment_end_offset;
         /** スレッドの最終更新日時 */
         apr_time_t      mtime;
         /** スレッドの最終 age 日時 */
         apr_time_t      atime;
         /** スレッドの生成日時 */
         apr_time_t      ctime;
+        /** コメント末尾のオフセット */
+        apr_size_t      comment_end_offset;
         /** スレッドのコメントの個数 */
         apr_uint16_t    comment_count;
         /** ディスクと同期していないコメントの数． */
@@ -376,10 +364,6 @@ private:
          */
         apr_size_t      comment_offsets[((TRD_MAX_COMMENT_COUNT-1) /
                                          TRD_COMMENT_OFFSET_PERIOD) + 1 + 1];
-#ifndef WIN32
-        // VisualStudio 2005 が挿入する謎のパディング
-        apr_size_t      padding;
-#endif
 
         bbs_thread() {
             // ゼロクリア
@@ -441,37 +425,21 @@ private:
      * @param[in] trip トリップ
      * @param[in] email メールアドレス
      * @param[in] message メッセージ
+     * @param[in] image 添付画像
      * @param[in] time 書き込み時刻
      * @param[in] is_age age かどうか
      * @return コメント
      */
     bbs_comment_t *add_comment_data(const char *name, const char *trip,
                                     const char *email, const char *message,
-                                    apr_time_t time, bool is_age);
-    /**
-     * コメントの内容をチェックします．
-     *
-     * @param[in] name 名前
-     * @param[in] trip トリップ
-     * @param[in] email メールアドレス
-     * @param[in] message メッセージ
-     * @param[in] is_age age かどうか
-     * @param[out] flag フラグ
-     */
-    void validate_comment(const char *name, const char *trip,
-                          const char *email, const char *message,
-                          bool is_age,
-                          BBSThread::bbs_comment_flag_t *flag) const;
+                                    BBSThread::image_t *image, apr_time_t time,
+                                    bool is_age);
     /**
      * コメントの番号をチェックします．
      *
      * @param[in] no 番号
      */
     void validate_no(apr_size_t no) const;
-    const image_t *get_image() const
-    {
-        return &(bthread_.image);
-    };
     /**
      * 日付をフォーマットします．
      *
@@ -497,7 +465,12 @@ private:
         bcomment_p->trip    = bcomment_p->name + bcomment->trip_offset;
         bcomment_p->email   = bcomment_p->name + bcomment->email_offset;
         bcomment_p->message = bcomment_p->name + bcomment->message_offset;
-        bcomment_p->message_length = bcomment->message_length;
+        bcomment_p->message_length  = bcomment->message_length;
+
+        bcomment_p->image_ext       = bcomment->image.ext;
+        bcomment_p->thumb_width     = bcomment->image.thumbnail.width;
+        bcomment_p->thumb_height    = bcomment->image.thumbnail.height;
+
         bcomment_p->flag_data = bcomment->flag_data;
     }
 #ifdef DEBUG
