@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.h 1898 2006-10-26 17:46:14Z svn $
+ * $Id: PostFlowController.h 1903 2006-10-29 13:13:56Z svn $
  *****************************************************************************/
 
 #ifndef POST_FLOW_CONTROLLER_H
@@ -33,8 +33,10 @@
 #include <cstdlib>
 
 #include "apr_shm.h"
+#include "apr_time.h"
 #include "apr_atomic.h"
 
+#include "Macro.h"
 #include "Uncopyable.h"
 
 using namespace std;
