@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: fast_bbs_util.h 1898 2006-10-26 17:46:14Z svn $
+ * $Id: fast_bbs_util.h 1946 2006-11-07 16:35:18Z svn $
  *****************************************************************************/
 
 #ifndef FAST_BBS_UTIL_H
@@ -56,6 +56,7 @@ static const char ARG_COMMENT_RANGE_INTERVAL_CHAR   = '-';
 static const char ARG_COMMENT_RANGE_LAST_STR[]      = "l";
 static const char ARG_ANCHOR_STR[]                  = "#";
 
+static const char FILE_TOKEN_SEPARATOR[]            = "_";
 static const char FILE_EXT_SEPARATOR[]              = ".";
 
 const char *get_word(apr_pool_t *pool, const char **input,
@@ -69,73 +70,6 @@ void get_thread_param(apr_pool_t *pool, const char *arg, apr_size_t *thread_id,
                       BBSCommentIterator::range_t **ranges,
                       apr_size_t *range_count);
 
-template<class R>
-void get_post_base_param(apr_pool_t *pool,
-                         apr_array_header_t *content_array,
-                         const char **name, const char **trip,
-                         const char **email, const char **message,
-                         apr_time_t *time, bool *is_age)
-{
-    typename RFC1867Parser<R>::content_t *name_content;
-    typename RFC1867Parser<R>::content_t *email_content;
-    typename RFC1867Parser<R>::content_t *message_content;
-
-    name_content = RFC1867Parser<R>::get_content(content_array,
-                                                 POST_NAME_PARAM);
-    email_content = RFC1867Parser<R>::get_content(content_array,
-                                                  POST_EMAIL_PARAM);
-    message_content = RFC1867Parser<R>::get_content(content_array,
-                                                    POST_MESSAGE_PARAM);
-
-    if ((name_content == NULL) ||
-        (name_content->type != RFC1867Parser<R>::TEXT) ||
-        (email_content == NULL) ||
-        (email_content->type != RFC1867Parser<R>::TEXT) ||
-        (message_content == NULL) ||
-        (message_content->type != RFC1867Parser<R>::TEXT)) {
-        THROW(MESSAGE_POST_DATA_INVALID);
-    }
-
-    if (strchr(name_content->text, POST_TRIP_SEPARATOR) != NULL) {
-        *trip = name_content->text;
-        *name = get_word(pool, trip, POST_TRIP_SEPARATOR);
-    } else {
-        *name = name_content->text;
-        *trip = "";
-    }
-
-    *email = email_content->text;
-    *message = message_content->text;
-    *time = apr_time_now();
-
-    *is_age = (strncmp(*email, POST_SAGE_SPECIFIER,
-                       LITERAL_STRLEN(POST_SAGE_SPECIFIER)) != 0);
-}
-
-template<class R>
-void get_post_comment_param(apr_pool_t *pool,
-                            apr_array_header_t *content_array,
-                            apr_size_t *thread_id,
-                            const char **name, const char **trip,
-                            const char **email, const char **message,
-                            apr_time_t *time, bool *is_age)
-{
-    typename RFC1867Parser<R>::content_t *thread_id_content;
-
-    thread_id_content = RFC1867Parser<R>::get_content(content_array,
-                                                      POST_THREAD_ID_PARAM);
-
-    if ((thread_id_content == NULL) ||
-        (thread_id_content->type != RFC1867Parser<R>::TEXT)) {
-        THROW(MESSAGE_POST_DATA_INVALID);
-    }
-
-    *thread_id = atosize(thread_id_content->text);
-
-    get_post_base_param<R>(pool, content_array, name, trip, email, message,
-                           time, is_age);
-}
-
 void get_thumbnail_size(ImageFile *image_file,
                         apr_uint16_t *width, apr_uint16_t *height);
 
@@ -157,46 +91,118 @@ void get_image_param(apr_pool_t *pool,
 }
 
 template<class R>
-void get_post_thread_param(apr_pool_t *pool,
-                           apr_array_header_t *content_array,
-                           const char **subject, BBSThread::image_t *image,
-                           const char **image_temp_path,
-                           const char **name, const char **trip,
-                           const char **email, const char **message,
-                           apr_time_t *time, bool *is_age)
+void get_post_base_param(apr_pool_t *pool,
+                         apr_array_header_t *content_array,
+                         const char **name, const char **trip,
+                         const char **email, const char **message,
+                         BBSThread::image_t *image,
+                         const char **image_temp_path,
+                         apr_time_t *time, bool *is_age)
 {
-    typename RFC1867Parser<R>::content_t *subject_content;
+    typename RFC1867Parser<R>::content_t *name_content;
+    typename RFC1867Parser<R>::content_t *email_content;
+    typename RFC1867Parser<R>::content_t *message_content;
     typename RFC1867Parser<R>::content_t *image_content;
 
-    subject_content = RFC1867Parser<R>::get_content(content_array,
-                                                    POST_SUBJECT_PARAM);
+    name_content = RFC1867Parser<R>::get_content(content_array,
+                                                 POST_NAME_PARAM);
+    email_content = RFC1867Parser<R>::get_content(content_array,
+                                                  POST_EMAIL_PARAM);
+    message_content = RFC1867Parser<R>::get_content(content_array,
+                                                    POST_MESSAGE_PARAM);
     image_content = RFC1867Parser<R>::get_content(content_array,
                                                   POST_IMAGE_PARAM);
 
-    if ((subject_content == NULL) ||
-        (subject_content->type != RFC1867Parser<R>::TEXT) ||
+    if ((name_content == NULL) ||
+        (name_content->type != RFC1867Parser<R>::TEXT) ||
+        (email_content == NULL) ||
+        (email_content->type != RFC1867Parser<R>::TEXT) ||
+        (message_content == NULL) ||
+        (message_content->type != RFC1867Parser<R>::TEXT) ||
         (image_content == NULL) ||
         (image_content->type != RFC1867Parser<R>::FILE)) {
         THROW(MESSAGE_POST_DATA_INVALID);
     }
 
-    *subject = subject_content->text;
+    if (strchr(name_content->text, POST_TRIP_SEPARATOR) != NULL) {
+        *trip = name_content->text;
+        *name = get_word(pool, trip, POST_TRIP_SEPARATOR);
+    } else {
+        *name = name_content->text;
+        *trip = "";
+    }
 
     if (image_content->file.size != 0) {
         get_image_param<R>(pool, image_content, image, image_temp_path);
     }
 
+    *email = email_content->text;
+    *message = message_content->text;
+    *time = apr_time_now();
+
+    *is_age = (strncmp(*email, POST_SAGE_SPECIFIER,
+                       LITERAL_STRLEN(POST_SAGE_SPECIFIER)) != 0);
+}
+
+template<class R>
+void get_post_comment_param(apr_pool_t *pool,
+                            apr_array_header_t *content_array,
+                            apr_size_t *thread_id,
+                            const char **name, const char **trip,
+                            const char **email, const char **message,
+                            BBSThread::image_t *image,
+                            const char **image_temp_path,
+                            apr_time_t *time, bool *is_age)
+{
+    typename RFC1867Parser<R>::content_t *thread_id_content;
+
+    thread_id_content = RFC1867Parser<R>::get_content(content_array,
+                                                      POST_THREAD_ID_PARAM);
+
+    if ((thread_id_content == NULL) ||
+        (thread_id_content->type != RFC1867Parser<R>::TEXT)) {
+        THROW(MESSAGE_POST_DATA_INVALID);
+    }
+
+    *thread_id = atosize(thread_id_content->text);
+
     get_post_base_param<R>(pool, content_array, name, trip, email, message,
-                           time, is_age);
+                           image, image_temp_path, time, is_age);
+}
+
+template<class R>
+void get_post_thread_param(apr_pool_t *pool,
+                           apr_array_header_t *content_array,
+                           const char **subject,
+                           const char **name, const char **trip,
+                           const char **email, const char **message,
+                           BBSThread::image_t *image,
+                           const char **image_temp_path,
+                           apr_time_t *time, bool *is_age)
+{
+    typename RFC1867Parser<R>::content_t *subject_content;
+
+    subject_content = RFC1867Parser<R>::get_content(content_array,
+                                                    POST_SUBJECT_PARAM);
+
+    if ((subject_content == NULL) ||
+        (subject_content->type != RFC1867Parser<R>::TEXT)) {
+        THROW(MESSAGE_POST_DATA_INVALID);
+    }
+
+    *subject = subject_content->text;
+
+    get_post_base_param<R>(pool, content_array, name, trip, email, message,
+                           image, image_temp_path, time, is_age);
 }
 
 void create_thumbnail(apr_pool_t *pool, const char *file_dir_path,
-                      apr_size_t thread_id, BBSThread::image_t *image,
-                      const char *image_temp_path);
+                      apr_size_t thread_id, apr_uint16_t comment_no,
+                      BBSThread::image_t *image, const char *image_temp_path);
 
 void commit_image_file(apr_pool_t *pool, const char *file_dir_path,
-                       apr_size_t thread_id, BBSThread::image_t *image,
-                       const char *image_temp_path);
+                       apr_size_t thread_id, apr_uint16_t comment_no,
+                       BBSThread::image_t *image, const char *image_temp_path);
 
 bool can_post(BBSConfig *config, const char *url);
 void regist_post(BBSConfig *config, const char *url);
