@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadManager.cpp 1824 2006-10-20 17:20:11Z svn $
+ * $Id: BBSThreadManager.cpp 1944 2006-11-07 14:35:58Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -48,7 +48,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 1824 2006-10-20 17:20:11Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 1944 2006-11-07 14:35:58Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -81,7 +81,7 @@ SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 1824 2006-10-20 17:20:11Z svn $");
 #define REQUIRE_MANAGER_LOCKED()
 #endif
 
-const apr_size_t BBSThreadManager::NULL_INDEX   = static_cast<apr_size_t>(-1);
+const apr_uint16_t BBSThreadManager::NULL_INDEX = static_cast<apr_uint16_t>(-1);
 
 /******************************************************************************
  * public メソッド
@@ -99,7 +99,7 @@ void BBSThreadManager::init(BBSThreadList *thread_list)
 void BBSThreadManager::get_thread_info_sort_by_view(apr_pool_t *pool,
                                                     apr_size_t *thread_count,
                                                     apr_size_t **ids_sort_by_view,
-                                                    apr_size_t **indexes_sort_by_view) const
+                                                    apr_uint16_t **indexes_sort_by_view) const
 {
     apr_size_t *thread_info;
     ReadLocker manager_locker(manager_ref_count_);
@@ -112,7 +112,7 @@ void BBSThreadManager::get_thread_info_sort_by_view(apr_pool_t *pool,
                 2 * sizeof(apr_size_t) * (*thread_count));
 
     *ids_sort_by_view = thread_info;
-    *indexes_sort_by_view = (*ids_sort_by_view) + (*thread_count);
+    *indexes_sort_by_view = AS_UINT16((*ids_sort_by_view) + (*thread_count));
 
     memcpy(*ids_sort_by_view, ids_sort_by_view_,
            sizeof(apr_size_t) * (*thread_count));
@@ -135,7 +135,7 @@ void BBSThreadManager::get_thread_by_id(apr_pool_t *pool,
 }
 
 void BBSThreadManager::get_thread_by_index(apr_pool_t *pool,
-                                           const apr_size_t i,
+                                           apr_uint16_t i,
                                            apr_size_t thread_id,
                                            BBSCommentIterator *bcomment_iter,
                                            BBSCommentIterator::range_t *ranges,
@@ -163,17 +163,16 @@ void BBSThreadManager::get_thread_by_index(apr_pool_t *pool,
 }
 
 apr_size_t BBSThreadManager::create_thread(const char *subject,
-                                           BBSThread::image_t *image,
-                                           const char *name,
-                                           const char *trip,
+                                           const char *name, const char *trip,
                                            const char *email,
                                            const char *message,
+                                           BBSThread::image_t *image,
                                            apr_time_t time, bool is_age)
 {
     WriteLocker manager_locker(manager_ref_count_);
     apr_size_t thread_id;
     BBSThread *bbs_thread;
-    apr_size_t i;
+    apr_uint16_t i;
 
     REQUIRE_MANAGER_LOCKED();
 
@@ -187,10 +186,10 @@ apr_size_t BBSThreadManager::create_thread(const char *subject,
         WriteLocker thread_locker(threads_ref_count_ + i);
         REQUIRE_THREAD_WRITE_LOCKED(i);
 
-        bbs_thread = create_and_add_comment(i, thread_id,
-                                            subject, image,
-                                            name, trip, email, message, time,
-                                            is_age, true);
+        bbs_thread = create_and_add_comment(thread_id, i,
+                                            subject, name, trip, email,
+                                            message, image,
+                                            time, is_age, true);
     } else {
         // メモリに空きがあるので，スレッドをそこへロード
         i = (*thread_count_)++;
@@ -198,10 +197,10 @@ apr_size_t BBSThreadManager::create_thread(const char *subject,
         WriteLocker thread_locker(threads_ref_count_ + i);
         REQUIRE_THREAD_WRITE_LOCKED(i);
 
-        bbs_thread = create_and_add_comment(i, thread_id,
-                                            subject, image,
-                                            name, trip, email, message, time,
-                                            is_age);
+        bbs_thread = create_and_add_comment(thread_id, i,
+                                            subject, name, trip, email,
+                                            message, image,
+                                            time, is_age);
     }
 
     // スレッドの存在を示すため，ファイルに書き出しておく．
@@ -212,27 +211,16 @@ apr_size_t BBSThreadManager::create_thread(const char *subject,
     return thread_id;
 }
 
-apr_size_t BBSThreadManager::create_thread(const char *subject,
-                                           const char *name,
-                                           const char *trip,
-                                           const char *email,
-                                           const char *message,
-                                           apr_time_t time, bool is_age)
-{
-    BBSThread::image_t image;
-
-    return create_thread(subject, &image,
-                         name, trip, email, message, time, is_age);
-}
-
-void BBSThreadManager::add_comment(apr_size_t thread_id,
-                                   const char *name, const char *trip,
-                                   const char *email, const char *message,
-                                   apr_time_t time, bool is_age)
+apr_size_t BBSThreadManager::add_comment(apr_size_t thread_id,
+                                         const char *name, const char *trip,
+                                         const char *email,
+                                         const char *message,
+                                         BBSThread::image_t *image,
+                                         apr_time_t time, bool is_age)
 {
     WriteLocker manager_locker(manager_ref_count_);
     BBSThread *bbs_thread;
-    apr_size_t i;
+    apr_uint16_t i;
 
     REQUIRE_MANAGER_LOCKED();
 
@@ -245,9 +233,11 @@ void BBSThreadManager::add_comment(apr_size_t thread_id,
         WriteLocker thread_locker(threads_ref_count_ + i);
         REQUIRE_THREAD_WRITE_LOCKED(i);
 
-        exec_add_comment(bbs_thread, i, name, trip, email, message, time,
-                         is_age);
+        exec_add_comment(bbs_thread, i, name, trip, email, message, image,
+                         time, is_age);
         thread_list_->update(bbs_thread);
+
+        return bbs_thread->get_comment_count();
     } else {
         // メモリ上にスレッドが無い
         if (LIKELY(*thread_count_ != MGR_ON_MEMORY_THREAD_COUNT)) {
@@ -256,8 +246,9 @@ void BBSThreadManager::add_comment(apr_size_t thread_id,
             WriteLocker thread_locker(threads_ref_count_ + i);
             REQUIRE_THREAD_WRITE_LOCKED(i);
 
-            read_and_add_comment(thread_id, i, name, trip, email, message,
-                                 time, is_age);
+            return read_and_add_comment(thread_id, i,
+                                        name, trip, email, message, image,
+                                        time, is_age);
         } else {
             // メモリが満杯なので，更新日時が古いものを書き出したあと，
             // スレッドをロード
@@ -266,8 +257,9 @@ void BBSThreadManager::add_comment(apr_size_t thread_id,
             WriteLocker thread_locker(threads_ref_count_ + i);
             REQUIRE_THREAD_WRITE_LOCKED(i);
 
-            read_and_add_comment(thread_id, i, name, trip, email, message,
-                                 time, is_age, true);
+            return read_and_add_comment(thread_id, i,
+                                        name, trip, email, message, image,
+                                        time, is_age, true);
         }
     }
 }
@@ -312,7 +304,7 @@ apr_size_t BBSThreadManager::get_memory_size()
 {
     return sizeof(BBSThreadManager) +
         (BBSThread::MAX_THREAD_DATA_SIZE + sizeof(apr_size_t)
-         + sizeof(apr_size_t) + sizeof(apr_size_t) + sizeof(apr_atomic_t)) *
+         + sizeof(apr_uint16_t) + sizeof(apr_uint16_t) + sizeof(apr_atomic_t)) *
         MGR_ON_MEMORY_THREAD_COUNT +
         sizeof(apr_size_t) + sizeof(apr_atomic_t);
 }
@@ -363,7 +355,8 @@ void BBSThreadManager::init_shm()
         = AS_SIZE(AS_CHAR(threads_) +
                   BBSThread::MAX_THREAD_DATA_SIZE*MGR_ON_MEMORY_THREAD_COUNT);
 
-    indexes_sort_by_view_ = ids_sort_by_view_ + MGR_ON_MEMORY_THREAD_COUNT;
+    indexes_sort_by_view_ = AS_UINT16(ids_sort_by_view_ +
+                                      MGR_ON_MEMORY_THREAD_COUNT);
     indexes_sort_by_mtime_ = indexes_sort_by_view_ + MGR_ON_MEMORY_THREAD_COUNT;
 
     manager_ref_count_ = AS_ATOMIC(indexes_sort_by_mtime_ + MGR_ON_MEMORY_THREAD_COUNT);
@@ -443,7 +436,7 @@ inline void BBSThreadManager::get_thread_by_id_without_lock(apr_pool_t *pool,
                                                             apr_size_t range_count) const
 {
     BBSThread *bbs_thread;
-    apr_size_t i;
+    apr_uint16_t i;
 
     bbs_thread = get_thread_by_id(thread_id);
 
@@ -465,7 +458,7 @@ inline void BBSThreadManager::get_thread_by_id_without_lock(apr_pool_t *pool,
     }
 }
 
-inline BBSThread *BBSThreadManager::get_thread_by_index(apr_size_t i,
+inline BBSThread *BBSThreadManager::get_thread_by_index(apr_uint16_t i,
                                                         bool is_check_index) const
 {
     if (is_check_index) {
@@ -483,9 +476,9 @@ inline BBSThread *BBSThreadManager::get_thread_by_index(apr_size_t i,
                          BBSThread::MAX_THREAD_DATA_SIZE*i);
 }
 
-inline apr_size_t BBSThreadManager::get_index_by_thread(BBSThread *bbs_thread) const
+inline apr_uint16_t BBSThreadManager::get_index_by_thread(BBSThread *bbs_thread) const
 {
-    apr_size_t i;
+    apr_uint16_t i;
 #ifdef __INTEL_COMPILER
 #pragma warning(push)
 #pragma warning(disable:1684)
@@ -510,9 +503,10 @@ inline apr_size_t BBSThreadManager::get_index_by_thread(BBSThread *bbs_thread) c
 }
 
 void BBSThreadManager::exec_add_comment(BBSThread *bbs_thread,
-                                        const apr_size_t i,
+                                        apr_uint16_t i,
                                         const char *name, const char *trip,
                                         const char *email, const char *message,
+                                        BBSThread::image_t *image,
                                         apr_time_t time, bool is_age,
                                         bool is_insert)
 {
@@ -523,7 +517,7 @@ void BBSThreadManager::exec_add_comment(BBSThread *bbs_thread,
         THROW(MESSAGE_BBS_THREAD_COMMENT_ADD_FORBIDDEN);
     }
 
-    bbs_thread->add_comment(name, trip, email, message, time, is_age);
+    bbs_thread->add_comment(name, trip, email, message, image, time, is_age);
 
     update_indexes_sort_by_mtime(i, is_insert);
 
@@ -538,13 +532,16 @@ void BBSThreadManager::exec_add_comment(BBSThread *bbs_thread,
     }
 }
 
-void BBSThreadManager::read_and_add_comment(apr_size_t thread_id,
-                                            const apr_size_t i,
-                                            const char *name, const char *trip,
-                                            const char *email,
-                                            const char *message,
-                                            apr_time_t time, bool is_age,
-                                            bool is_need_write)
+apr_uint16_t BBSThreadManager::read_and_add_comment(apr_size_t thread_id,
+                                                    apr_uint16_t i,
+                                                    const char *name,
+                                                    const char *trip,
+                                                    const char *email,
+                                                    const char *message,
+                                                    BBSThread::image_t *image,
+                                                    apr_time_t time,
+                                                    bool is_age,
+                                                    bool is_need_write)
 {
     BBSThread *bbs_thread;
 
@@ -559,18 +556,21 @@ void BBSThreadManager::read_and_add_comment(apr_size_t thread_id,
     }
 
     thread_reader_.read(thread_id, bbs_thread);
-    exec_add_comment(bbs_thread, i, name, trip, email, message, time, is_age);
+    exec_add_comment(bbs_thread, i, name, trip, email, message, image, time,
+                     is_age);
     thread_list_->update(bbs_thread);
+
+    return bbs_thread->get_comment_count();
 }
 
-BBSThread * BBSThreadManager::create_and_add_comment(const apr_size_t i,
-                                                     apr_size_t thread_id,
+BBSThread * BBSThreadManager::create_and_add_comment(apr_size_t thread_id,
+                                                     apr_uint16_t i,
                                                      const char *subject,
-                                                     BBSThread::image_t *image,
                                                      const char *name,
                                                      const char *trip,
                                                      const char *email,
                                                      const char *message,
+                                                     BBSThread::image_t *image,
                                                      apr_time_t time,
                                                      bool is_age,
                                                      bool is_need_write)
@@ -586,11 +586,10 @@ BBSThread * BBSThreadManager::create_and_add_comment(const apr_size_t i,
         write_thread(bbs_thread);
     }
 
-    bbs_thread = BBSThread::get_instance(bbs_thread, thread_id, subject, image,
-                                         time);
+    bbs_thread = BBSThread::get_instance(bbs_thread, thread_id, subject, time);
 
-    exec_add_comment(bbs_thread, i, name, trip, email, message, time, is_age,
-                     true);
+    exec_add_comment(bbs_thread, i, name, trip, email, message, image, time,
+                     is_age, true);
 
     return bbs_thread;
 }
@@ -616,43 +615,42 @@ apr_size_t BBSThreadManager::create_thread_id() const
     return thread_id;
 }
 
-void BBSThreadManager::update_indexes_sort_by_view(apr_size_t i,
+void BBSThreadManager::update_indexes_sort_by_view(apr_uint16_t i,
                                                    apr_size_t thread_id,
                                                    bool is_insert)
 {
-    update_indexes(indexes_sort_by_view_, i, is_insert);
-    update_indexes(ids_sort_by_view_, thread_id, is_insert);
+    update_array<apr_uint16_t>(indexes_sort_by_view_, i, is_insert);
+    update_array<apr_size_t>(ids_sort_by_view_, thread_id, is_insert);
 }
 
-void BBSThreadManager::update_indexes_sort_by_mtime(apr_size_t i,
+void BBSThreadManager::update_indexes_sort_by_mtime(apr_uint16_t i,
                                                     bool is_insert)
 {
-    update_indexes(indexes_sort_by_mtime_, i, is_insert);
+    update_array<apr_uint16_t>(indexes_sort_by_mtime_, i, is_insert);
 }
 
-void BBSThreadManager::update_indexes(apr_size_t *indexes, apr_size_t i,
-                                      bool is_insert)
+template<class T>
+void BBSThreadManager::update_array(T *array, T i, bool is_insert)
 {
     apr_size_t j;
 
     REQUIRE_MANAGER_LOCKED();
 
     if (is_insert) {
-        memmove(indexes + 1, indexes,
-                sizeof(apr_size_t) * (get_thread_count() - 1));
-        indexes[0] = i;
+        memmove(array + 1, array, sizeof(T) * (get_thread_count() - 1));
+        array[0] = i;
 
         return;
     }
 
-    if (indexes[0] == i) {
+    if (array[0] == i) {
         // 既に先頭に i があれば何もする必要がない
         return;
     }
 
     j = NULL_INDEX;
     for (apr_size_t k = 1; k < get_thread_count(); k++) {
-        if (indexes[k] == i) {
+        if (array[k] == i) {
             j = k;
             break;
         }
@@ -664,8 +662,8 @@ void BBSThreadManager::update_indexes(apr_size_t *indexes, apr_size_t i,
     }
 #endif
 
-    memmove(indexes + 1, indexes, sizeof(apr_size_t) * j);
-    indexes[0] = i;
+    memmove(array + 1, array, sizeof(T) * j);
+    array[0] = i;
 }
 
 int BBSThreadManager::cmp_indexes_by_mtime(apr_size_t left, apr_size_t right) const
@@ -764,7 +762,7 @@ static void run_read_by_index(apr_pool_t *pool,
                               BBSThreadManager *thread_manager,
                               apr_size_t thread_count,
                               apr_size_t *ids_sort_by_view,
-                              apr_size_t *indexes_sort_by_view)
+                              apr_uint16_t *indexes_sort_by_view)
 {
     volatile double start_time;
     volatile double end_time;
@@ -828,7 +826,7 @@ static void run_all_read(apr_pool_t *pool, BBSThreadManager *thread_manager)
 {
     apr_size_t thread_count;
     apr_size_t *ids_sort_by_view;
-    apr_size_t *indexes_sort_by_view;
+    apr_uint16_t *indexes_sort_by_view;
 
     show_test_name("read");
 
