@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: fast_bbs_util.cpp 1887 2006-10-22 18:49:12Z svn $
+ * $Id: fast_bbs_util.cpp 1946 2006-11-07 16:35:18Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -31,11 +31,12 @@
 
 #include "fast_bbs_util.h"
 
+#include "BBSConfig.h"
 #include "BBSThreadIO.h"
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: fast_bbs_util.cpp 1887 2006-10-22 18:49:12Z svn $");
+SOURCE_INFO_ADD("$Id: fast_bbs_util.cpp 1946 2006-11-07 16:35:18Z svn $");
 
 const char *get_word(apr_pool_t *pool, const char **input,
                      const char delimiter)
@@ -138,6 +139,10 @@ void get_thumbnail_size(ImageFile *image_file,
     *width = image_file->get_width();
     *height = image_file->get_height();
 
+    if (((*width) == 0) || ((*height) == 0)) {
+        THROW(MESSAGE_POST_IMAGE_SIZE_INVALID);
+    }
+
     if ((static_cast<double>(*width)/(*height)) > THUMBAIL_ASPECT) {
         // 横長の場合
         if ((*width) > VIW_THUMBNAIL_WIDTH_LIMIT) {
@@ -151,17 +156,23 @@ void get_thumbnail_size(ImageFile *image_file,
             *height = VIW_THUMBNAIL_HEIGHT_LIMIT;
         }
     }
+
+    if (((*width) == 0) || ((*height) == 0)) {
+        THROW(MESSAGE_POST_IMAGE_SIZE_INVALID);
+    }
 }
 
 void create_thumbnail(apr_pool_t *pool, const char *file_dir_path,
-                      apr_size_t thread_id, BBSThread::image_t *image,
-                      const char *image_temp_path)
+                      apr_size_t thread_id, apr_uint16_t comment_no,
+                      BBSThread::image_t *image, const char *image_temp_path)
 {
     const char *thumbnail_path;
 
     thumbnail_path = BBSThreadIO::get_file_path
         (pool, file_dir_path, thread_id,
          apr_pstrcat(pool, apr_itoa(pool, static_cast<int>(thread_id)),
+                     FILE_TOKEN_SEPARATOR,
+                     apr_itoa(pool, static_cast<int>(comment_no)),
                      VIW_THUMBNAIL_SUFFIX,
                      FILE_EXT_SEPARATOR, VIW_THUMBNAIL_EXT,
                      NULL));
@@ -176,8 +187,8 @@ void create_thumbnail(apr_pool_t *pool, const char *file_dir_path,
 }
 
 void commit_image_file(apr_pool_t *pool, const char *file_dir_path,
-                       apr_size_t thread_id, BBSThread::image_t *image,
-                       const char *image_temp_path)
+                       apr_size_t thread_id, apr_uint16_t comment_no,
+                       BBSThread::image_t *image, const char *image_temp_path)
 {
     const char *image_path;
 
@@ -185,13 +196,16 @@ void commit_image_file(apr_pool_t *pool, const char *file_dir_path,
     image_path = BBSThreadIO::get_file_path
         (pool, file_dir_path, thread_id,
          apr_pstrcat(pool, apr_itoa(pool, static_cast<int>(thread_id)),
+                     FILE_TOKEN_SEPARATOR,
+                     apr_itoa(pool, static_cast<int>(comment_no)),
                      FILE_EXT_SEPARATOR, image->ext, NULL));
 
     if (apr_file_rename(image_temp_path, image_path, pool) != APR_SUCCESS) {
         THROW(MESSAGE_POST_IMAGE_COMMIT_FAILED);
     }
 
-    create_thumbnail(pool, file_dir_path, thread_id, image, image_path);
+    create_thumbnail(pool, file_dir_path,
+                     thread_id, comment_no, image, image_path);
 }
 
 bool can_post(BBSConfig *config, const char *url)
